==> jc-1.4.0.tar.gz: gnu/java/text/BaseBreakIterator.h <==
// public abstract class gnu.java.text.BaseBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header java_text_BreakIterator

#include "java/text/BreakIterator.h"

#ifndef _JC_gnu_java_text_BaseBreakIterator_H_
#define _JC_gnu_java_text_BaseBreakIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_text_CharacterIterator$object;

// Typedefs
typedef struct _jc_gnu_java_text_BaseBreakIterator$sub_refs	_jc_gnu_java_text_BaseBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	_jc_gnu_java_text_BaseBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_BaseBreakIterator$refs	_jc_gnu_java_text_BaseBreakIterator$refs;
typedef struct _jc_gnu_java_text_BaseBreakIterator$nonrefs	_jc_gnu_java_text_BaseBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_BaseBreakIterator$object	_jc_gnu_java_text_BaseBreakIterator$object;

typedef const struct _jc_gnu_java_text_BaseBreakIterator$vmethods	_jc_gnu_java_text_BaseBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_BaseBreakIterator$vtable	_jc_gnu_java_text_BaseBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_BaseBreakIterator$vtype	_jc_gnu_java_text_BaseBreakIterator$vtype;

// Constructors
extern void _jc_gnu_java_text_BaseBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);

// Virtual methods
extern jint _jc_gnu_java_text_BaseBreakIterator$method$current$de03efd4e521699d(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);
extern jint _jc_gnu_java_text_BaseBreakIterator$method$first$90820f61e7793b47(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);
extern jint _jc_gnu_java_text_BaseBreakIterator$method$following$a862063bb4ef32f8(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, jint);
extern struct _jc_object *_jc_gnu_java_text_BaseBreakIterator$method$getText$7b46d83e85f75cef(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);
extern jint _jc_gnu_java_text_BaseBreakIterator$method$last$5c9b35436f0d83f0(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);
extern jint _jc_gnu_java_text_BaseBreakIterator$method$next$e62cd7126ad5e76f(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, jint);
extern void _jc_gnu_java_text_BaseBreakIterator$method$setText$9c02a33aa9b10f14(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$current$de03efd4e521699d;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$first$90820f61e7793b47;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$following$a862063bb4ef32f8;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$getText$7b46d83e85f75cef;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$last$5c9b35436f0d83f0;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$next$e62cd7126ad5e76f;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$setText$9c02a33aa9b10f14;

// Virtual methods structure
struct _jc_gnu_java_text_BaseBreakIterator$vmethods {
	jint	(*current$de03efd4e521699d)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);
	jint	(*first$90820f61e7793b47)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);
	jint	(*following$a862063bb4ef32f8)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, jint);
	struct _jc_object	*(*getText$7b46d83e85f75cef)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);
	jint	(*last$5c9b35436f0d83f0)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *);
	jint	(*next$e62cd7126ad5e76f)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, jint);
	void	(*setText$9c02a33aa9b10f14)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_text_BaseBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_BaseBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_BaseBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_BaseBreakIterator$sub_refs {
	struct _jc_object	*iter;
};

// Reference instance fields (object)
struct _jc_gnu_java_text_BaseBreakIterator$refs {
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_BaseBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_BaseBreakIterator$object {
	_jc_gnu_java_text_BaseBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_BaseBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_BaseBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_BaseBreakIterator$vtype _jc_gnu_java_text_BaseBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_BaseBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_BaseBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_BaseBreakIterator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/text/BaseBreakIterator.h <==
// public abstract class gnu.java.text.BaseBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header java_text_BreakIterator

#include "java/text/BreakIterator.h"

#ifndef _JC_gnu_java_text_BaseBreakIterator_H_
#define _JC_gnu_java_text_BaseBreakIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_text_CharacterIterator$object;

// Typedefs
typedef struct _jc_gnu_java_text_BaseBreakIterator$sub_refs	_jc_gnu_java_text_BaseBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	_jc_gnu_java_text_BaseBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_BaseBreakIterator$refs	_jc_gnu_java_text_BaseBreakIterator$refs;
typedef struct _jc_gnu_java_text_BaseBreakIterator$nonrefs	_jc_gnu_java_text_BaseBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_BaseBreakIterator$object	_jc_gnu_java_text_BaseBreakIterator$object;

typedef const struct _jc_gnu_java_text_BaseBreakIterator$vmethods	_jc_gnu_java_text_BaseBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_BaseBreakIterator$vtable	_jc_gnu_java_text_BaseBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_BaseBreakIterator$vtype	_jc_gnu_java_text_BaseBreakIterator$vtype;

// Constructors
extern void _jc_gnu_java_text_BaseBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_text_BaseBreakIterator$method$current$de03efd4e521699d(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_BaseBreakIterator$method$first$90820f61e7793b47(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_BaseBreakIterator$method$following$a862063bb4ef32f8(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_text_BaseBreakIterator$method$getText$7b46d83e85f75cef(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_BaseBreakIterator$method$last$5c9b35436f0d83f0(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_BaseBreakIterator$method$next$e62cd7126ad5e76f(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_text_BaseBreakIterator$method$setText$9c02a33aa9b10f14(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$current$de03efd4e521699d;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$first$90820f61e7793b47;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$following$a862063bb4ef32f8;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$getText$7b46d83e85f75cef;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$last$5c9b35436f0d83f0;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$next$e62cd7126ad5e76f;
extern _jc_method _jc_gnu_java_text_BaseBreakIterator$method_info$setText$9c02a33aa9b10f14;

// Virtual methods structure
struct _jc_gnu_java_text_BaseBreakIterator$vmethods {
	jint	(*current$de03efd4e521699d)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*first$90820f61e7793b47)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*following$a862063bb4ef32f8)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*getText$7b46d83e85f75cef)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*last$5c9b35436f0d83f0)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*next$e62cd7126ad5e76f)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, jint) _JC_JCNI_ATTR;
	void	(*setText$9c02a33aa9b10f14)(_jc_env *, struct _jc_gnu_java_text_BaseBreakIterator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_text_BaseBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_BaseBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_BaseBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_BaseBreakIterator$sub_refs {
	struct _jc_object	*iter;
};

// Reference instance fields (object)
struct _jc_gnu_java_text_BaseBreakIterator$refs {
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_BaseBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_BaseBreakIterator$object {
	_jc_gnu_java_text_BaseBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_BaseBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_BaseBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_BaseBreakIterator$vtype _jc_gnu_java_text_BaseBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_BaseBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_BaseBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_BaseBreakIterator_H_ */
